/*****************************************************************
* Unipro UGENE - Integrated Bioinformatics Suite
* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
* All Rights Reserved
* 
*     This source code is distributed under the terms of the
*     GNU General Public License. See the files COPYING and LICENSE
*     for details.
*****************************************************************/

#ifndef _U2_EXPORT_SEQ2MSA_DIALOG_H_
#define _U2_EXPORT_SEQ2MSA_DIALOG_H_

#include <U2Core/global.h>

#include <QtGui/QDialog>
#include <ui/ui_ExportSequences2MSADialog.h>

namespace U2 {

class SaveDocumentGroupController;

class ExportSequences2MSADialog : public QDialog, Ui_ExportSequences2MSADialog {
    Q_OBJECT
public:
    ExportSequences2MSADialog(QWidget* p, const QString& defaultUrl = QString() );
    
    void setOkButtonText(const QString& text) const;
    void setFileLabelText(const QString& text) const;

    virtual void accept();


public:    
    QString url;
    DocumentFormatId format;
    bool    addToProjectFlag;

private:    
    SaveDocumentGroupController* saveContoller;

};

}//namespace

#endif
